from .base_config import BaseConfig, ModelConfig

from dataclasses import dataclass, field

from hydra.core.config_store import ConfigStore


features_to_use = [
    "acc_x",
    "acc_y",
    "acc_z",
    "rot_w",
    "rot_x",
    "rot_y",
    "rot_z",
    "acc_gx",
    "acc_gy",
    "acc_gz_no_gravity",
    "acc_magnitude",
    "alpha",
    "beta",
    "gamma",
]


label_category_to_int = {
    "Above ear - pull hair": 0,
    "Cheek - pinch skin": 0,
    "Drink from bottle/cup": 1,
    "Eyebrow - pull hair": 0,
    "Eyelash - pull hair": 0,
    "Feel around in tray and pull out an object": 1,
    "Forehead - pull hairline": 0,
    "Forehead - scratch": 0,
    "Glasses on/off": 1,
    "Neck - pinch skin": 0,
    "Neck - scratch": 0,
    "Pinch knee/leg skin": 1,
    "Pull air toward your face": 1,
    "Scratch knee/leg skin": 1,
    "Text on phone": 1,
    "Wave hello": 1,
    "Write name in air": 1,
    "Write name on leg": 1,
}


@dataclass
class AttentionModelConfig(ModelConfig):
    d_model: int = 16
    n_head: int = 4
    num_layers: int = 2
    num_classes: int = 2
    input_dim: int = len(features_to_use)
    name: str = "a2_tcnt_2"


@dataclass
class TransformTcnGlobalFeaturesConfig(BaseConfig):
    features_to_use: list[str] = field(default_factory=lambda: features_to_use)
    model: AttentionModelConfig = field(default_factory=AttentionModelConfig)
    label_category_to_int: dict = field(default_factory=lambda: label_category_to_int)

    patience: int = 10


def register_config():
    cs = ConfigStore.instance()
    cs.store(name="config", node=TransformTcnGlobalFeaturesConfig)
