from dataclasses import dataclass, field

from hydra.core.config_store import ConfigStore


features_to_use = [
    "acc_x",
    "acc_y",
    "acc_z",
    "rot_w",
    "rot_x",
    "rot_y",
    "rot_z",
]

label_category_to_int = {
    "Above ear - pull hair": 0,
    "Cheek - pinch skin": 1,
    "Drink from bottle/cup": 2,
    "Eyebrow - pull hair": 3,
    "Eyelash - pull hair": 4,
    "Feel around in tray and pull out an object": 5,
    "Forehead - pull hairline": 6,
    "Forehead - scratch": 7,
    "Glasses on/off": 8,
    "Neck - pinch skin": 9,
    "Neck - scratch": 10,
    "Pinch knee/leg skin": 11,
    "Pull air toward your face": 12,
    "Scratch knee/leg skin": 13,
    "Text on phone": 14,
    "Wave hello": 15,
    "Write name in air": 16,
    "Write name on leg": 17,
}


@dataclass
class ModelConfig:
    num_classes: int = 18
    input_channel: int = len(features_to_use)
    d_length: int = 103
    name: str = "model"


@dataclass
class GaussianNoiseConfig:
    probability: float = 0.5
    noise_std: float = 0.01


@dataclass
class BaseConfig:
    max_sequence_count: int = 103
    num_classes: int = 18
    features_to_use: list[str] = field(default_factory=lambda: features_to_use)
    features_to_check: list[str] = field(
        default_factory=lambda: [
            "acc_x",
            "acc_y",
            "acc_z",
            "rot_w",
            "rot_x",
            "rot_y",
            "rot_z",
        ]
    )
    target_label: str = "gesture"
    id_features: list[str] = field(
        default_factory=lambda: ["sequence_id", "sequence_counter"]
    )

    label_category_to_int: dict[str, int] = field(
        default_factory=lambda: label_category_to_int
    )

    model: ModelConfig = field(default_factory=ModelConfig)
    gaussian_noise: GaussianNoiseConfig = field(default_factory=GaussianNoiseConfig)

    valid_split: float = 0.2
    max_epochs: int = 200
    patience: int = 6
    min_delta: float = 0.0
    use_tensorboard: bool = True


def register_config():
    cs = ConfigStore.instance()
    cs.store(name="config", node=BaseConfig)
