from .base_config import BaseConfig, ModelConfig

from dataclasses import dataclass, field

from hydra.core.config_store import ConfigStore


features_to_use = [
    "acc_x",
    "acc_y",
    "acc_z",
    "rot_w",
    "rot_x",
    "rot_y",
    "rot_z",
    "acc_gx",
    "acc_gy",
    "acc_gz_no_gravity",
    "acc_magnitude",
    "alpha",
    "beta",
    "gamma",
]


@dataclass
class AttentionModelConfig(ModelConfig):
    d_model: int = 16
    n_head: int = 4
    num_layers: int = 2
    num_classes: int = 18
    input_dim: int = len(features_to_use)
    name: str = "transformer_tcn_global_features"


@dataclass
class TransformTcnGlobalFeaturesConfig(BaseConfig):
    features_to_use: list[str] = field(default_factory=lambda: features_to_use)
    model: AttentionModelConfig = field(default_factory=AttentionModelConfig)


def register_config():
    cs = ConfigStore.instance()
    cs.store(name="config", node=TransformTcnGlobalFeaturesConfig)
