import torch
from torch import nn
from torch.nn import functional as F


from omegaconf.dictconfig import DictConfig


class ConvModel1(nn.Module):
    """My model"""

    def __init__(
        self,
        input_channel: int,
        num_classes: int,
        d_length: int,
        name: str = "model",
    ):
        super().__init__()
        self.input_channel = input_channel
        self.num_classes = num_classes
        self.d_length = d_length
        self.name = name

        self.cv_1 = nn.Conv1d(
            input_channel, 64, kernel_size=3, stride=1, padding="same"
        )
        self.cv_2 = nn.Conv1d(64, 64, kernel_size=3, stride=1, padding="same")
        self.mx = nn.MaxPool1d(kernel_size=2, stride=2)

        # self.flatten = nn.Flatten()
        self.global_avg_pool = nn.AdaptiveAvgPool1d(1)
        self.ff = nn.Linear(64, num_classes)

    @classmethod
    def from_config(cls, cfg: DictConfig) -> "ConvModel1":
        if "input_channel" not in cfg:
            raise ValueError("cfg.input_channel is required")

        if "num_classes" not in cfg:
            raise ValueError("cfg.num_classes is required")

        if "d_length" not in cfg:
            raise ValueError("cfg.d_length is required")

        if "name" not in cfg:
            name = f"model_{cfg.input_dim}"
            print(f"cfg.name wasn't defined, using default name: {name}")
        else:
            name = cfg.name

        return cls(
            input_channel=cfg.input_channel,
            num_classes=cfg.num_classes,
            d_length=cfg.d_length,
            name=name,
        )

    def forward(
        self,
        x: torch.Tensor,
    ) -> torch.Tensor:
        """Processes the data

        Args:
            x (torch.Tensor): data

        Returns:
            torch.Tensor: result of the processing
        """
        x = F.relu(self.cv_1(x))
        x = F.relu(self.cv_2(x))
        x = self.mx(x)

        x = self.global_avg_pool(x)
        x = x.squeeze(-1)
        x = self.ff(x)

        return x
