from typing import Callable

import polars as pl

import torch
from torch import nn


def predict_sequence(
    sequence: pl.DataFrame,
    model: nn.Module,
    prs: list[Callable],
    transforms: list[Callable],
    label_int_to_category: dict[int, str],
    device: str,
):
    for pr in prs:
        sequence = pr(sequence)

    for transform in transforms:
        sequence = transform(sequence)

    sequence = sequence

    model.eval()
    with torch.inference_mode():
        sequence = [x.to(device) for x in sequence]
        sequence = [x.unsqueeze(0) for x in sequence]
        prediction = model(sequence)
        prediction = prediction.squeeze().argmax().item()

    return label_int_to_category[prediction]
